{"changed":true,"filter":false,"title":"README.md","tooltip":"/README.md","value":"# h265ize\nh265ize is a fire and forget weapon. A nodejs utility utilizing ffmpeg to encode large quantities of videos with the hevc codec.\nFor more information visit [ayrton.sparling.us](https://ayrton.sparling.us/index.php/ultimate-x265hevc-encoding-script-h265ize/ \"Ayrton Sparling\").\n\n[![NPM License](https://img.shields.io/npm/l/h265ize.svg)](https://raw.githubusercontent.com/FallingSnow/h265ize/master/LICENSE) [![NPM Version](https://img.shields.io/npm/v/h265ize.svg)](https://www.npmjs.com/package/h265ize)\n\nIf you have any questions or h265ize isn't working for you, feel free to open an issue.\n\n## Features\n- Works on Windows, OSX, and Linux\n- Batch file processing (can process a whole folder)\n- Automatically detects video files (only processes video files found within a folder)\n- Detects all audio tracks\n- Preserves audio codecs\n- Preserves audio track titles\n- Detects and preserves all subtitles\n- Detects audio language, if audio language is not your native language and native language subtitles are provided, makes those subtitles default\n- Automatically upconvert vobsub/dvdsubs to srt subtitles on mkv files\n- Detects bit depth and uses appropriate encoder profile (10-bit is common in high quality anime, supports 8-bit, 10-bit, 12-bit)\n- Verbose and preview mode\n- File overwrite detection (doesn't accidentally write over a file that already exists, other than in preview mode)\n- Detects if file is already encoded in x265 and skips it\n- Ability to make encoding previews\n- Take screenshots of a finished encode\n- Fallback ffmpeg/ffprobe binary if ffmpeg is not installed\n- Faulty encoding detection based on before and after video durations\n- Maintains file structure in output folder (So in theory you could just take your 3tb movie folder and throw it into the script and the output folder should look that same but with x265 videos)\n\n### Dependencies\n- [Node.js](https://nodejs.org/en/) - Required in order to run h265ize.\n- [ffmpeg](https://ffmpeg.org/) - Does the video conversion among other things.\n\n#### Option Dependencies\n- [mkvtoolnix](https://www.bunkus.org/videotools/mkvtoolnix/) - Used for upconverting subs in MKVs.\n- [vobsub2srt](https://github.com/ruediger/VobSub2SRT) - Used for upconverting subs.\n\n### Installation\nTo install h265ize run one of the following command lines to download and install.\n\n##### Base Utility\n```\nnpm install h265ize --global\n```\n\n##### Arch Linux (Plus Dependencies)\n```\nsudo pacman -S nodejs mkvtoolnix-cli; \\\nyaourt vobsub2srt-git; \\\nnpm install h265ize --global\n```\n\n##### Bleeding Edge/Development\n```\ngit clone https://github.com/FallingSnow/h265ize.git && cd h265ize && npm install && chmod +x h265ize\n```\n\n### Updating\nSimply run `npm install h265ize --global` again.\n\n## Usage\n`h265ize [--help] [-d <string>] [-q <0-51>] [-m <string>] [-n <string>] [-f <string>{3}] [-g <string>] [-l <integer>] [-o] [-p] [-v] [--10bit] [--12bit] [--accurate-timestamps] [--as-preset <preset>] [--disable-upconvert] [--no-auto-subtitle-titles] [--debug] [--video-bitrate <integer>] [--he-audio] [--force-he-audio] [--he-downmix] [--no-auto-audio-titles] [--screenshots] [--delete] <file|directory>`\n\n### Options\n> -d :Folder to output files to\n\n> -f :Container format to output; Options: mkv, mp4, m4v; default: mkv.\n\n> -g :Directory where new unfinished file is stored\n\n> -l :Milliseconds to be encoded in preview mode; default: 30000\n\n> -m :x265 encoder preset; Options: ultrafast, superfast, veryfast, faster, fast, medium, slow, slower, veryslow, placebo; default: fast\n\n> -n :The native language used to select default audio and subtitles. You may use 3 letter or 2 letter ISO 639-2 Alpha-3/Alpha-2 codes or the full language name. Examples: [eng|en|English|jpn|ja|Japanese]\n\n> -o :Override mode; Allows conversion of videos that are already encoded by the hevc codec\n\n> -p :Preview mode; Only process a 30 second preview\n\n> -q :Sets the qp quality target; default: 19\n\n> -v :Verbose mode; Display extra output\n\n> -x :Extra x265 options. Options can be found on the [x265 options page](https://x265.readthedocs.org/en/default/cli.html)\n\n> --10bit :Forces encoding videos in 10bit format (Useful for anime)\n\n> --12bit :Forces encoding videos in 12bit format (Useful for anime)\n\n> --accurate-timestamps :Accurate Timestamps (substantially increases file size but sometimes fixes timestamps)\n\n> --as-preset :My personal presets; Possible values are listed below; I'll be adding more as time goes on\n\n> --debug :Debug mode; Print extra debugging information\n\n> --delete :Deletes source after encoding is complete and replaces it with new encode; STRONGLY NOT RECOMMENED\n\n> --disable-upconvert :Disable Upconvert; Stop converting Vobsub subs to srt; Only works with mkv's\n\n> --force-he-audio :Force High Efficiency audio encoding even on lossless audio tracks\n\n> --he-audio :High Efficiency audio mode\n\n> --he-downmix :If there are more than 2.1 audio channels, downmix them to stereo. **`he-audio` must also be enabled**\n\n> --no-auto-audio-titles :Disable automated title generation for audio streams that do not have preexisting titles.\n\n> --no-auto-subtitle-titles :Disable automated title generation for subtitle streams that do not have preexisting titles.\n\n> --screenshots :Take 6 screenshots at regular intervals throughout the finished encode\n\n> --stats: Creates a stats file in the destination named h265ize.csv\n\n> --video-bitrate :Sets the video bitrate, set to 0 to use qp instead of a target bitrate\n\n> --test: Test mode; Runs as normal, but do not encode any files\n\n> --help :Help; Shows help page\n\n> --version: Show version information\n\nRun `h265ize --help` for more info.\n\n#### Aspresets <a name=\"aspresets\"></a>\n| Preset | Description |\n|:---:|:---|\n| basic | Overall good preset, will always create high quality videos but may produce large files. |\n| anime | A very good preset for all types of anime. Produces very good quality for a very small size. Warning: this preset creates a nonconformant, high latency encode. |\n| testing-ssim | x265's native preset just in SSIM mode. |\n\n#### Examples\n* `./h265izer -v big_buck_bunny_1080p_h264.mov`\n* `./h265izer -v -d /home -q 25 -g /home big_buck_bunny_folder`\n\n## Stats file\nThe stats file is located at the current working directory under the name `h265ize.csv`. This must be enabled using the `--stats` flag. The file is composed of several lines. Each line is in the format\n\n`[Finish Encoding Date],[Filename],[Original Size],[Encoded size],[Compression Precent],[Encoding Duration]`\n\nFor exmaple:\n\n`08/13 02:46:03 PM, [deanzel] Noir - 08 [BD 1080p Hi10p Dual Audio FLAC][a436a4e8].mkv, 1964MB, 504MB, 25.00%`\n\n## Creating 10bit encodes\nTo create 10bit or 12bit encodes, simply pass the `--10bit` or `--12bit` parameters respecively. You may need to install `x265_main10` and `x265_main12` (x265 main10 and main12 libraries) in order to encode in 10/12 bit.","undoManager":{"mark":137,"position":139,"stack":[[{"start":{"row":28,"column":71},"end":{"row":29,"column":71},"action":"insert","lines":["","- [Node.js](https://nodejs.org/en/) - Required in order to run h265ize."],"id":1}],[{"start":{"row":29,"column":3},"end":{"row":29,"column":10},"action":"remove","lines":["Node.js"],"id":2},{"start":{"row":29,"column":3},"end":{"row":29,"column":4},"action":"insert","lines":["f"]}],[{"start":{"row":29,"column":4},"end":{"row":29,"column":5},"action":"insert","lines":["f"],"id":3}],[{"start":{"row":29,"column":5},"end":{"row":29,"column":6},"action":"insert","lines":["m"],"id":4}],[{"start":{"row":29,"column":6},"end":{"row":29,"column":7},"action":"insert","lines":["p"],"id":5}],[{"start":{"row":29,"column":7},"end":{"row":29,"column":8},"action":"insert","lines":["e"],"id":6}],[{"start":{"row":29,"column":8},"end":{"row":29,"column":9},"action":"insert","lines":["g"],"id":7}],[{"start":{"row":29,"column":37},"end":{"row":29,"column":68},"action":"remove","lines":["Required in order to run h265iz"],"id":8}],[{"start":{"row":29,"column":37},"end":{"row":29,"column":38},"action":"remove","lines":["e"],"id":9}],[{"start":{"row":29,"column":37},"end":{"row":29,"column":38},"action":"insert","lines":["D"],"id":10}],[{"start":{"row":29,"column":38},"end":{"row":29,"column":39},"action":"insert","lines":["o"],"id":11}],[{"start":{"row":29,"column":39},"end":{"row":29,"column":40},"action":"insert","lines":["e"],"id":12}],[{"start":{"row":29,"column":40},"end":{"row":29,"column":41},"action":"insert","lines":["s"],"id":13}],[{"start":{"row":29,"column":41},"end":{"row":29,"column":42},"action":"insert","lines":[" "],"id":14}],[{"start":{"row":29,"column":42},"end":{"row":29,"column":43},"action":"insert","lines":["t"],"id":15}],[{"start":{"row":29,"column":43},"end":{"row":29,"column":44},"action":"insert","lines":["h"],"id":16}],[{"start":{"row":29,"column":44},"end":{"row":29,"column":45},"action":"insert","lines":["e"],"id":17}],[{"start":{"row":29,"column":45},"end":{"row":29,"column":46},"action":"insert","lines":[" "],"id":18}],[{"start":{"row":29,"column":46},"end":{"row":29,"column":47},"action":"insert","lines":["v"],"id":19}],[{"start":{"row":29,"column":47},"end":{"row":29,"column":48},"action":"insert","lines":["i"],"id":20}],[{"start":{"row":29,"column":48},"end":{"row":29,"column":49},"action":"insert","lines":["d"],"id":21}],[{"start":{"row":29,"column":49},"end":{"row":29,"column":50},"action":"insert","lines":["e"],"id":22}],[{"start":{"row":29,"column":50},"end":{"row":29,"column":51},"action":"insert","lines":["o"],"id":23}],[{"start":{"row":29,"column":50},"end":{"row":29,"column":51},"action":"remove","lines":["o"],"id":24}],[{"start":{"row":29,"column":50},"end":{"row":29,"column":51},"action":"insert","lines":["o"],"id":25}],[{"start":{"row":29,"column":51},"end":{"row":29,"column":52},"action":"insert","lines":[" "],"id":26}],[{"start":{"row":29,"column":52},"end":{"row":29,"column":53},"action":"insert","lines":["c"],"id":27}],[{"start":{"row":29,"column":53},"end":{"row":29,"column":54},"action":"insert","lines":["o"],"id":28}],[{"start":{"row":29,"column":54},"end":{"row":29,"column":55},"action":"insert","lines":["n"],"id":29}],[{"start":{"row":29,"column":55},"end":{"row":29,"column":56},"action":"insert","lines":["v"],"id":30}],[{"start":{"row":29,"column":56},"end":{"row":29,"column":57},"action":"insert","lines":["e"],"id":31}],[{"start":{"row":29,"column":57},"end":{"row":29,"column":58},"action":"insert","lines":["r"],"id":32}],[{"start":{"row":29,"column":58},"end":{"row":29,"column":59},"action":"insert","lines":["s"],"id":33}],[{"start":{"row":29,"column":59},"end":{"row":29,"column":60},"action":"insert","lines":["i"],"id":34}],[{"start":{"row":29,"column":60},"end":{"row":29,"column":61},"action":"insert","lines":["o"],"id":35}],[{"start":{"row":29,"column":61},"end":{"row":29,"column":62},"action":"insert","lines":["n"],"id":36}],[{"start":{"row":29,"column":62},"end":{"row":29,"column":63},"action":"insert","lines":[" "],"id":37}],[{"start":{"row":29,"column":63},"end":{"row":29,"column":64},"action":"insert","lines":["a"],"id":38}],[{"start":{"row":29,"column":64},"end":{"row":29,"column":65},"action":"insert","lines":["m"],"id":39}],[{"start":{"row":29,"column":65},"end":{"row":29,"column":66},"action":"insert","lines":["o"],"id":40}],[{"start":{"row":29,"column":66},"end":{"row":29,"column":67},"action":"insert","lines":["n"],"id":41}],[{"start":{"row":29,"column":67},"end":{"row":29,"column":68},"action":"insert","lines":["g"],"id":42}],[{"start":{"row":29,"column":68},"end":{"row":29,"column":69},"action":"insert","lines":[" "],"id":43}],[{"start":{"row":29,"column":69},"end":{"row":29,"column":70},"action":"insert","lines":["o"],"id":44}],[{"start":{"row":29,"column":70},"end":{"row":29,"column":71},"action":"insert","lines":["t"],"id":45}],[{"start":{"row":29,"column":71},"end":{"row":29,"column":72},"action":"insert","lines":["h"],"id":46}],[{"start":{"row":29,"column":72},"end":{"row":29,"column":73},"action":"insert","lines":["e"],"id":47}],[{"start":{"row":29,"column":73},"end":{"row":29,"column":74},"action":"insert","lines":["r"],"id":48}],[{"start":{"row":29,"column":74},"end":{"row":29,"column":75},"action":"insert","lines":[" "],"id":49}],[{"start":{"row":29,"column":75},"end":{"row":29,"column":76},"action":"insert","lines":["t"],"id":50}],[{"start":{"row":29,"column":76},"end":{"row":29,"column":77},"action":"insert","lines":["h"],"id":51}],[{"start":{"row":29,"column":77},"end":{"row":29,"column":78},"action":"insert","lines":["i"],"id":52}],[{"start":{"row":29,"column":78},"end":{"row":29,"column":79},"action":"insert","lines":["n"],"id":53}],[{"start":{"row":29,"column":79},"end":{"row":29,"column":80},"action":"insert","lines":["g"],"id":54}],[{"start":{"row":29,"column":80},"end":{"row":29,"column":81},"action":"insert","lines":["s"],"id":55}],[{"start":{"row":29,"column":11},"end":{"row":29,"column":33},"action":"remove","lines":["https://nodejs.org/en/"],"id":56},{"start":{"row":29,"column":11},"end":{"row":29,"column":30},"action":"insert","lines":["https://ffmpeg.org/"]}],[{"start":{"row":23,"column":39},"end":{"row":24,"column":0},"action":"insert","lines":["",""],"id":58},{"start":{"row":24,"column":0},"end":{"row":24,"column":2},"action":"insert","lines":["- "]}],[{"start":{"row":24,"column":2},"end":{"row":24,"column":3},"action":"insert","lines":["F"],"id":59}],[{"start":{"row":24,"column":3},"end":{"row":24,"column":4},"action":"insert","lines":["a"],"id":60}],[{"start":{"row":24,"column":4},"end":{"row":24,"column":5},"action":"insert","lines":["l"],"id":61}],[{"start":{"row":24,"column":5},"end":{"row":24,"column":6},"action":"insert","lines":["b"],"id":62}],[{"start":{"row":24,"column":6},"end":{"row":24,"column":7},"action":"insert","lines":["a"],"id":63}],[{"start":{"row":24,"column":7},"end":{"row":24,"column":8},"action":"insert","lines":["c"],"id":64}],[{"start":{"row":24,"column":8},"end":{"row":24,"column":9},"action":"insert","lines":["k"],"id":65}],[{"start":{"row":24,"column":8},"end":{"row":24,"column":9},"action":"remove","lines":["k"],"id":66}],[{"start":{"row":24,"column":7},"end":{"row":24,"column":8},"action":"remove","lines":["c"],"id":67}],[{"start":{"row":24,"column":6},"end":{"row":24,"column":7},"action":"remove","lines":["a"],"id":68}],[{"start":{"row":24,"column":5},"end":{"row":24,"column":6},"action":"remove","lines":["b"],"id":69}],[{"start":{"row":24,"column":5},"end":{"row":24,"column":6},"action":"insert","lines":["l"],"id":70}],[{"start":{"row":24,"column":6},"end":{"row":24,"column":7},"action":"insert","lines":["b"],"id":71}],[{"start":{"row":24,"column":7},"end":{"row":24,"column":8},"action":"insert","lines":["a"],"id":72}],[{"start":{"row":24,"column":8},"end":{"row":24,"column":9},"action":"insert","lines":["c"],"id":73}],[{"start":{"row":24,"column":9},"end":{"row":24,"column":10},"action":"insert","lines":["k"],"id":74}],[{"start":{"row":24,"column":10},"end":{"row":24,"column":11},"action":"insert","lines":[" "],"id":75}],[{"start":{"row":24,"column":11},"end":{"row":24,"column":12},"action":"insert","lines":["f"],"id":76}],[{"start":{"row":24,"column":12},"end":{"row":24,"column":13},"action":"insert","lines":["f"],"id":77}],[{"start":{"row":24,"column":13},"end":{"row":24,"column":14},"action":"insert","lines":["m"],"id":78}],[{"start":{"row":24,"column":14},"end":{"row":24,"column":15},"action":"insert","lines":["p"],"id":79}],[{"start":{"row":24,"column":15},"end":{"row":24,"column":16},"action":"insert","lines":["e"],"id":80}],[{"start":{"row":24,"column":16},"end":{"row":24,"column":17},"action":"insert","lines":["g"],"id":81}],[{"start":{"row":24,"column":17},"end":{"row":24,"column":18},"action":"insert","lines":[" "],"id":82}],[{"start":{"row":24,"column":18},"end":{"row":24,"column":19},"action":"insert","lines":["b"],"id":83}],[{"start":{"row":24,"column":19},"end":{"row":24,"column":20},"action":"insert","lines":["i"],"id":84}],[{"start":{"row":24,"column":20},"end":{"row":24,"column":21},"action":"insert","lines":["n"],"id":85}],[{"start":{"row":24,"column":21},"end":{"row":24,"column":22},"action":"insert","lines":["a"],"id":86}],[{"start":{"row":24,"column":22},"end":{"row":24,"column":23},"action":"insert","lines":["r"],"id":87}],[{"start":{"row":24,"column":23},"end":{"row":24,"column":24},"action":"insert","lines":["y"],"id":88}],[{"start":{"row":24,"column":17},"end":{"row":24,"column":18},"action":"insert","lines":["/"],"id":89}],[{"start":{"row":24,"column":18},"end":{"row":24,"column":19},"action":"insert","lines":["f"],"id":90}],[{"start":{"row":24,"column":19},"end":{"row":24,"column":20},"action":"insert","lines":["f"],"id":91}],[{"start":{"row":24,"column":20},"end":{"row":24,"column":21},"action":"insert","lines":["p"],"id":92}],[{"start":{"row":24,"column":21},"end":{"row":24,"column":22},"action":"insert","lines":["r"],"id":93}],[{"start":{"row":24,"column":22},"end":{"row":24,"column":23},"action":"insert","lines":["r"],"id":94}],[{"start":{"row":24,"column":23},"end":{"row":24,"column":24},"action":"insert","lines":["o"],"id":95}],[{"start":{"row":24,"column":24},"end":{"row":24,"column":25},"action":"insert","lines":["b"],"id":96}],[{"start":{"row":24,"column":24},"end":{"row":24,"column":25},"action":"remove","lines":["b"],"id":97}],[{"start":{"row":24,"column":23},"end":{"row":24,"column":24},"action":"remove","lines":["o"],"id":98}],[{"start":{"row":24,"column":22},"end":{"row":24,"column":23},"action":"remove","lines":["r"],"id":99}],[{"start":{"row":24,"column":22},"end":{"row":24,"column":23},"action":"insert","lines":["o"],"id":100}],[{"start":{"row":24,"column":23},"end":{"row":24,"column":24},"action":"insert","lines":["b"],"id":101}],[{"start":{"row":24,"column":24},"end":{"row":24,"column":25},"action":"insert","lines":["e"],"id":102}],[{"start":{"row":24,"column":32},"end":{"row":24,"column":33},"action":"insert","lines":[" "],"id":103}],[{"start":{"row":24,"column":33},"end":{"row":24,"column":34},"action":"insert","lines":["i"],"id":104}],[{"start":{"row":24,"column":34},"end":{"row":24,"column":35},"action":"insert","lines":["f"],"id":105}],[{"start":{"row":24,"column":35},"end":{"row":24,"column":36},"action":"insert","lines":[" "],"id":106}],[{"start":{"row":24,"column":36},"end":{"row":24,"column":37},"action":"insert","lines":["f"],"id":107}],[{"start":{"row":24,"column":37},"end":{"row":24,"column":38},"action":"insert","lines":["f"],"id":108}],[{"start":{"row":24,"column":38},"end":{"row":24,"column":39},"action":"insert","lines":["m"],"id":109}],[{"start":{"row":24,"column":39},"end":{"row":24,"column":40},"action":"insert","lines":["p"],"id":110}],[{"start":{"row":24,"column":40},"end":{"row":24,"column":41},"action":"insert","lines":["e"],"id":111}],[{"start":{"row":24,"column":41},"end":{"row":24,"column":42},"action":"insert","lines":["g"],"id":112}],[{"start":{"row":24,"column":42},"end":{"row":24,"column":43},"action":"insert","lines":[" "],"id":113}],[{"start":{"row":24,"column":43},"end":{"row":24,"column":44},"action":"insert","lines":["i"],"id":114}],[{"start":{"row":24,"column":44},"end":{"row":24,"column":45},"action":"insert","lines":["s"],"id":115}],[{"start":{"row":24,"column":45},"end":{"row":24,"column":46},"action":"insert","lines":[" "],"id":116}],[{"start":{"row":24,"column":46},"end":{"row":24,"column":47},"action":"insert","lines":["n"],"id":117}],[{"start":{"row":24,"column":47},"end":{"row":24,"column":48},"action":"insert","lines":["o"],"id":118}],[{"start":{"row":24,"column":48},"end":{"row":24,"column":49},"action":"insert","lines":["t"],"id":119}],[{"start":{"row":24,"column":49},"end":{"row":24,"column":50},"action":"insert","lines":[" "],"id":120}],[{"start":{"row":24,"column":50},"end":{"row":24,"column":51},"action":"insert","lines":["i"],"id":121}],[{"start":{"row":24,"column":51},"end":{"row":24,"column":52},"action":"insert","lines":["n"],"id":122}],[{"start":{"row":24,"column":52},"end":{"row":24,"column":53},"action":"insert","lines":["s"],"id":123}],[{"start":{"row":24,"column":53},"end":{"row":24,"column":54},"action":"insert","lines":["t"],"id":124}],[{"start":{"row":24,"column":54},"end":{"row":24,"column":55},"action":"insert","lines":["a"],"id":125}],[{"start":{"row":24,"column":55},"end":{"row":24,"column":56},"action":"insert","lines":["l"],"id":126}],[{"start":{"row":24,"column":56},"end":{"row":24,"column":57},"action":"insert","lines":["l"],"id":127}],[{"start":{"row":24,"column":57},"end":{"row":24,"column":58},"action":"insert","lines":["e"],"id":128}],[{"start":{"row":24,"column":58},"end":{"row":24,"column":59},"action":"insert","lines":["d"],"id":129}],[{"start":{"row":41,"column":19},"end":{"row":41,"column":20},"action":"insert","lines":[" "],"id":130}],[{"start":{"row":41,"column":20},"end":{"row":41,"column":21},"action":"insert","lines":["-"],"id":131}],[{"start":{"row":41,"column":21},"end":{"row":41,"column":22},"action":"insert","lines":["-"],"id":132}],[{"start":{"row":41,"column":22},"end":{"row":41,"column":23},"action":"insert","lines":["g"],"id":133}],[{"start":{"row":41,"column":23},"end":{"row":41,"column":24},"action":"insert","lines":["l"],"id":134}],[{"start":{"row":41,"column":24},"end":{"row":41,"column":25},"action":"insert","lines":["o"],"id":135}],[{"start":{"row":41,"column":25},"end":{"row":41,"column":26},"action":"insert","lines":["b"],"id":136}],[{"start":{"row":41,"column":26},"end":{"row":41,"column":27},"action":"insert","lines":["a"],"id":137}],[{"start":{"row":41,"column":26},"end":{"row":41,"column":27},"action":"remove","lines":["a"],"id":138}],[{"start":{"row":41,"column":22},"end":{"row":41,"column":26},"action":"remove","lines":["glob"],"id":139},{"start":{"row":41,"column":22},"end":{"row":41,"column":28},"action":"insert","lines":["global"]}],[{"start":{"row":60,"column":2},"end":{"row":60,"column":3},"action":"remove","lines":["/"],"id":140}],[{"start":{"row":60,"column":1},"end":{"row":60,"column":2},"action":"remove","lines":["."],"id":141}]]},"ace":{"folds":[],"scrolltop":600,"scrollleft":0,"selection":{"start":{"row":60,"column":52},"end":{"row":60,"column":52},"isBackwards":false},"options":{"guessTabSize":true,"useWrapMode":false,"wrapToView":true},"firstLineState":{"row":39,"state":"start","mode":"ace/mode/markdown"}},"timestamp":1470017943344}